@@ -218,6 +218,9 @@ def calc_new_range_hypos(search_x_func, func, ax_limit, ax_idx):
 def update_ax_range(ax_idx, memo, func):
 	# 着目軸のmemo
 	ax_memo = memo["ax_memo"][ax_idx]
+	# range_hyposが幅0の場合はこの軸の探索をスキップする
+	rh_L, rh_R = ax_memo["range_hypos"]
+	if rh_L == rh_R: return None
 	# memoからpivot位置を取得
 	pivot_vec = get_pivot_vec(memo)
 	# 探索点を出力する関数を生成 (pivotの着目軸のみrange_hypos内の内分点に書き換えたもの)
@@ -263,6 +266,7 @@ def is_optimal(
 	func,	# 最適化対象関数
 	x,	# 検査したい解
 	delta,	# 許容誤差
+	lim_range,	# 各軸の範囲
 	direction = "minimize"	# 最大化 / 最小化
 ):
 	if direction != "maximize": raise Exception("[error] maximize以外は未実装です")
@@ -272,7 +276,10 @@ def is_optimal(
 	for ax_i in range(dim_n):
 		for sign in [-1, 1]:
 			check_x = copy.copy(x)
-			check_x[ax_i] += sign * delta
+			new_value = check_x[ax_i] + sign * delta
+			# チェック点が範囲外の場合はチェックしない (その方向はすでに最適であるとみなす)
+			if judge_within(new_value, lim_range[ax_i]) is False: continue	# 値がlimit内にあるかどうかを判定 (両端含む)
+			check_x[ax_i] = new_value
 			y = func(check_x)
 			# 誤っている場合
 			if y > base_y: return False
@@ -359,6 +366,7 @@ class OptunaStudy:
 			func = self.wrapper_func,	# 最適化対象関数
 			x = self.best_x,	# 検査したい解
 			delta = delta,	# 許容誤差
+			lim_range = self.info["lim_range"],	# 各軸の範囲
 			direction = self.direction	# 最大化 / 最小化
 		)
 
